bread.contrib.reports package
=============================

.. automodule:: bread.contrib.reports
   :members:
   :undoc-members:
   :show-inheritance:

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   bread.contrib.reports.fields

Submodules
----------

bread.contrib.reports.models module
-----------------------------------

.. automodule:: bread.contrib.reports.models
   :members:
   :undoc-members:
   :show-inheritance:

bread.contrib.reports.urls module
---------------------------------

.. automodule:: bread.contrib.reports.urls
   :members:
   :undoc-members:
   :show-inheritance:
